==> ejc-assistrmat-impl-3.0.0-20220322.040153-2-sources.jar: com/ejianc/business/assist/rmat/bean/ChangeRepairEntity.java <==
package com.ejianc.business.assist.rmat.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 周转材租赁合同-维修标准变更表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_assistrmat_contract_change_repair")
public class ChangeRepairEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="change_id")
    private Long changeId; // 变更主键
    @TableField(value="change_type")
    private String changeType; // 变更类型
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="source_id")
    private Long sourceId; // 来源数据Id(参照数据id)
    @TableField(value="source_bid")
    private Long sourceBid; // 来源子表主键(合同子表id)
    @TableField(value="source_type")
    private String sourceType; // 来源类型：0-定标结果带入，1-总计划，2-材料档案，3-批次计划
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资材料分类Id
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资材料分类名称
    @TableField(value="material_name")
    private String materialName; // 材料名称
    @TableField(value="spec")
    private String spec; // 规则/型号
    @TableField(value="repair_item_name")
    private String repairItemName; // 维修项名称
    @TableField(value="repair_price")
    private BigDecimal repairPrice; // 维修单价(无税)
    @TableField(value="repair_tax_price")
    private BigDecimal repairTaxPrice; // 维修单价
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="tax")
    private BigDecimal tax; // 税额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="material_id")
    private Long materialId; // 材料id
    @TableField(value="material_code")
    private String materialCode; // 材料编码
    @TableField(value="unit_id")
    private Long unitId; // 计量单位id
    @TableField(value="unit_name")
    private String unitName; // 计量单位名称
    @TableField(value="repair_unit_id")
    private Long repairUnitId; // 维修单位id
    @TableField(value="repair_unit_name")
    private String repairUnitName; // 维修单位名称
    
    
    

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceBid() {
        return sourceBid;
    }

    public void setSourceBid(Long sourceBid) {
        this.sourceBid = sourceBid;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    
    public String getRepairItemName() {
        return repairItemName;
    }

    public void setRepairItemName(String repairItemName) {
        this.repairItemName = repairItemName;
    }
    
    public BigDecimal getRepairPrice() {
        return repairPrice;
    }

    public void setRepairPrice(BigDecimal repairPrice) {
        this.repairPrice = repairPrice;
    }
    public BigDecimal getRepairTaxPrice() {
        return repairTaxPrice;
    }

    public void setRepairTaxPrice(BigDecimal repairTaxPrice) {
        this.repairTaxPrice = repairTaxPrice;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public Long getRepairUnitId() {
        return repairUnitId;
    }

    public void setRepairUnitId(Long repairUnitId) {
        this.repairUnitId = repairUnitId;
    }
    public String getRepairUnitName() {
        return repairUnitName;
    }

    public void setRepairUnitName(String repairUnitName) {
        this.repairUnitName = repairUnitName;
    }
    
}

==> ejc-assistrmat-impl-3.0.0-20220415.115924-73-sources.jar: com/ejianc/business/assist/rmat/bean/ChangeRepairEntity.java <==
package com.ejianc.business.assist.rmat.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 周转材租赁合同-维修标准变更表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_assistrmat_contract_change_repair")
public class ChangeRepairEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="change_id")
    private Long changeId; // 变更主键
    @TableField(value="change_type")
    private String changeType; // 变更类型
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="source_id")
    private Long sourceId; // 来源数据Id(参照数据id)
    @TableField(value="source_bid")
    private Long sourceBid; // 来源子表主键(合同子表id)
    @TableField(value="source_type")
    private String sourceType; // 来源类型：0-定标结果带入，1-总计划，2-材料档案，3-批次计划
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资材料分类Id
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资材料分类名称
    @TableField(value="material_name")
    private String materialName; // 材料名称
    @TableField(value="spec")
    private String spec; // 规则/型号
    @TableField(value="repair_item_name")
    private String repairItemName; // 维修项名称
    @TableField(value="repair_price")
    private BigDecimal repairPrice; // 维修单价(无税)
    @TableField(value="repair_tax_price")
    private BigDecimal repairTaxPrice; // 维修单价
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="tax")
    private BigDecimal tax; // 税额
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="material_id")
    private Long materialId; // 材料id
    @TableField(value="material_code")
    private String materialCode; // 材料编码
    @TableField(value="unit_id")
    private Long unitId; // 计量单位id
    @TableField(value="unit_name")
    private String unitName; // 计量单位名称
    @TableField(value="repair_unit_id")
    private Long repairUnitId; // 维修单位id
    @TableField(value="repair_unit_name")
    private String repairUnitName; // 维修单位名称
    @TableField(value="material_type_code")
    private String materialTypeCode; // 材料分类编码
    @TableField(value="row_type")
    private Integer rowType; // 行分类：0-分类，1-材料
    

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceBid() {
        return sourceBid;
    }

    public void setSourceBid(Long sourceBid) {
        this.sourceBid = sourceBid;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    
    public String getRepairItemName() {
        return repairItemName;
    }

    public void setRepairItemName(String repairItemName) {
        this.repairItemName = repairItemName;
    }
    
    public BigDecimal getRepairPrice() {
        return repairPrice;
    }

    public void setRepairPrice(BigDecimal repairPrice) {
        this.repairPrice = repairPrice;
    }
    public BigDecimal getRepairTaxPrice() {
        return repairTaxPrice;
    }

    public void setRepairTaxPrice(BigDecimal repairTaxPrice) {
        this.repairTaxPrice = repairTaxPrice;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public Long getRepairUnitId() {
        return repairUnitId;
    }

    public void setRepairUnitId(Long repairUnitId) {
        this.repairUnitId = repairUnitId;
    }
    public String getRepairUnitName() {
        return repairUnitName;
    }

    public void setRepairUnitName(String repairUnitName) {
        this.repairUnitName = repairUnitName;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public Integer getRowType() {
        return rowType;
    }

    public void setRowType(Integer rowType) {
        this.rowType = rowType;
    }

}
